@@ -326,7 +326,8 @@ while (time < $s) {
 if ($XX > 255) {
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
-    for (my $c = 8 ; $c < 400 ; $c += (20 * $factor)) {
+    my $g = time + $factor;
+    while( time < $g) {
         my $x  = int(rand(600 * $xm));
         my $y  = int(rand(900 * $ym));
         my $h  = int(rand(300 * $ym));
@@ -336,7 +337,7 @@ if ($XX > 255) {
             {
                 'x'            => $x,
                   'y'            => $y,
-                  'height'       => $c * $ym,
+                  'height'       => $h,
                   'wscale'       => $ws,
                   'color'        => sprintf('%x%x%x%x', int(rand(256)), int(rand(256)), int(rand(256)), 255),
                   'text'         => 'GFB',
@@ -431,6 +432,8 @@ $s = time + $factor;
 while (time < $s) {
     my $image = $F->load_image(
         {
+            'x' => 0,
+              'y' => 0,
             'width'  => rand($XX),
               'height' => rand($YY),
               'file'   => 'examples/RWBY_Faces.png'
