@@ -40,7 +40,7 @@ my $top = 16 * $Threads; # Font height * # of threads
 
 $framebuffer[0]->cls('OFF');
 cls;
-print STDERR setscroll(1,$Threads); # prevents Perl errors from flooding the screen
+print STDERR setscroll(1,$Threads) if ($screen_width > 255); # prevents Perl errors from flooding the screen
 $SIG{'QUIT'} = \&finish;
 $SIG{'INT'}  = \&finish;
 my @thrd;
@@ -51,20 +51,20 @@ foreach my $page (1..$Threads) {
             my $Page = shift;
             my $top  = shift;
             if (defined($framebuffer[$Page]->{'ERROR'})) {
-                print STDERR locate($Page,1),clline,"ERROR: Thread $Page, $framebuffer[$Page]->{'ERROR'}";
+                print STDERR locate($Page,1),clline,"ERROR: Thread $Page, $framebuffer[$Page]->{'ERROR'}" if ($screen_width > 255);
             }
-            $framebuffer[$page]->clip_set({'x' => 0, 'y' => $top,'xx' => $screen_width,'yy'=>$screen_height});
+            $framebuffer[$page]->clip_set({'x' => 0, 'y' => $top,'xx' => $screen_width,'yy'=>$screen_height}) if ($screen_width > 255);
             while($RUNNING) {
                 attract($Page);
                 while($hold && $RUNNING) {
-                    print locate($Page,1),clline,colored(['white on_yellow'],"Thread $Page"),' Waiting for other threads to finish drawing before clearing screen...';
+                    print locate($Page,1),clline,colored(['white on_yellow'],"Thread $Page"),' Waiting for other threads to finish drawing before clearing screen...' if ($screen_width > 255);
                     threads->yield();
                     $waiting[$Page] = 0;
                     sleep 1;
                 }
                 $waiting[$Page] = 1;
             }
-            print locate($Page+1,1),clline,colored(['black on_green'],"Thread $Page"),' Finished';
+            print locate($Page+1,1),clline,colored(['black on_green'],"Thread $Page"),' Finished' if ($screen_width > 255);
         },
         $page,$top
     );
